@@ -19,17 +19,13 @@
 
 #include "../config.h"
 
-#ifdef HAVE_AVCODEC
-#ifdef HAVE_AVFORMAT
-#ifdef HAVE_AVUTIL
+#ifdef HAVE_LIBAV
 
-#ifdef FFMPEG_AVCODEC
-#include <ffmpeg/avcodec.h>
-#include <ffmpeg/avformat.h>
-#else
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
-#include <libavutil/dict.h>
+
+#ifdef HAVE_SWRESAMPLE
+#include <libswresample/swresample.h>
 #endif
 
 #include "xlplayer.h"
@@ -46,15 +42,20 @@ struct avcodecdecode_vars
     int resample;
     unsigned int stream;
     AVFrame *frame;
-    float *floatsamples;
     float drop;
     struct mp3taginfo taginfo;
     struct chapter *current_chapter;
+    int channels;   /* number of downmixed channels 1 or 2 */
+
+#ifdef HAVE_SWRESAMPLE
+    SwrContext *swr;
+    uint8_t *floatsamples;
+#else
+    float *floatsamples;
+#endif
+
     };
 
 int avcodecdecode_reg(struct xlplayer *xlplayer);
-void avformatinfo(char *pathname);
 
-#endif /* HAVE_AVUTIL */
-#endif /* HAVE_AVFORMAT */
-#endif /* HAVE_AVCODEC */
+#endif /* HAVE_LIBAV */
