@@ -134,6 +134,8 @@ struct encoder
     int n_channels;                      /* stream parameters information... */
     int bitrate;
     float pregain;                /* gain value to apply to audio before encoding */
+    float fadegain;                 /* encoder fadeout value */
+    float fadescale;                /* encoder fadeout rate */
     long samplerate;
     long target_samplerate;
     double sr_conv_ratio;
@@ -145,6 +147,7 @@ struct encoder
     pthread_mutex_t flush_mutex; /* to block encoder so it's in a known state before flush */
     pthread_mutex_t mutex;/* for blocking encoder_unregister_client while the encoder is writing out data */
     pthread_mutex_t metadata_mutex;      /* used when metadata is read or written */
+    pthread_mutex_t fade_mutex;     /* for blocking fade initiate while fade being processed */
     struct encoder_op *output_chain;     /* one output buffer per client connection */
     struct encoder_header_buffer *header_buffer; /* point to needed headers or NULL */
     enum performance_warning performance_warning_indicator; /* indicates ringbuffer overflow condition */
@@ -173,6 +176,7 @@ struct encoder_op *encoder_register_client(struct threads_info *ti, int numeric_
 void encoder_unregister_client(struct encoder_op *op);
 int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_stop(struct threads_info *ti, struct universal_vars *uv, void *other);
+int encoder_initiate_fade(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_update(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_song_metadata(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_custom_metadata(struct threads_info *ti, struct universal_vars *uv, void *other);
