@@ -29,6 +29,7 @@ from . import licence_window
 from . import songdb
 from . import midicontrols
 from .gtkstuff import WindowSizeTracker, DefaultEntry, threadslock
+from .gtkstuff import timeout_add, source_remove
 from .prelims import ProfileManager
 from .utils import PathStr
 from .tooltips import set_tip, MAIN_TIPS
@@ -176,9 +177,9 @@ class PanWidget(gtk.Frame):
             print "Attempt made to load a non existent pan preset"
         else:
             if self._source_id:
-                glib.source_remove(self._source_id)
+                source_remove(self._source_id)
                 
-            self._source_id = glib.timeout_add(5, self._timeout, target)
+            self._source_id = timeout_add(5, self._timeout, target)
 
     @threadslock
     def _timeout(self, target):
@@ -377,6 +378,8 @@ class AGCControl(gtk.Frame):
     def cb_open(self, widget):
         active = widget.get_active()
         self.meter.set_led(active)
+        if gtk.main_level():
+            self.approot.channelstate_changed(self.index, active)
 
     def cb_mode(self, combobox):
         mode = combobox.get_active()
@@ -1568,6 +1571,21 @@ class mixprefs:
             ("<b>fr</b> nvignot (nicotux@users.sf.net)",
             "<b>it</b>  Raffaele Morelli (raffaele.morelli@gmail.com)"))
 
+        label = gtk.Label(_('Build Info'))
+        ivbox = gtk.VBox()
+        ivbox.set_spacing(10)
+        ivbox.set_border_width(10)
+        nb.append_page(ivbox, label)
+        ivbox.show()
+
+        with open(FGlobs.pkgdatadir / "buildinfo") as f:
+            for each in f:
+                label = gtk.Label(each.rstrip())
+                label.set_use_markup(True)
+                label.set_selectable(True)
+                ivbox.pack_start(label, False)
+                label.show()
+
         vbox.show()
 
         aboutlabel = gtk.Label(_('About'))
